@@ -85,6 +85,7 @@ extern int     cap_get_flag(cap_t, cap_value_t, cap_flag_t, cap_flag_value_t *);
 extern int     cap_set_flag(cap_t, cap_flag_t, int, const cap_value_t *,
 			    cap_flag_value_t);
 extern int     cap_clear(cap_t);
+extern int     cap_clear_flag(cap_t, cap_flag_t);
 
 /* libcap/cap_file.c */
 extern cap_t   cap_get_fd(int);
@@ -111,7 +112,6 @@ extern int capset(cap_user_header_t header, cap_user_data_t data);
 extern int capget(cap_user_header_t header, const cap_user_data_t data);
 extern int capgetp(pid_t pid, cap_t cap_d);
 extern int capsetp(pid_t pid, cap_t cap_d);
-extern char const *_cap_names[];
 
 #ifdef __cplusplus
 }
